"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateDescribeInsightRules = void 0;
const CloudWatch_1 = require("../CloudWatch");
const CloudWatchClient_1 = require("../CloudWatchClient");
const DescribeInsightRulesCommand_1 = require("../commands/DescribeInsightRulesCommand");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new DescribeInsightRulesCommand_1.DescribeInsightRulesCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.describeInsightRules(input, ...args);
};
async function* paginateDescribeInsightRules(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof CloudWatch_1.CloudWatch) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof CloudWatchClient_1.CloudWatchClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected CloudWatch | CloudWatchClient");
        }
        yield page;
        const prevToken = token;
        token = page.NextToken;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateDescribeInsightRules = paginateDescribeInsightRules;
